q3rcon
=================

[![Pypi version](http://img.shields.io/pypi/v/acoomans_python_project_template.svg)](https://pypi.python.org/pypi/acoomans_python_project_template)
[![Pypi license](http://img.shields.io/pypi/l/acoomans_python_project_template.svg)](https://pypi.python.org/pypi/acoomans_python_project_template)
![Python 3](http://img.shields.io/badge/python-3-blue.svg)

## Install

    pip install q3rcon

or

	python setup.py install

## Usage

Run console:

    q3rcon-cli [hostname]

Run web server:

    q3rcon-web --rcon_host HOST --rcon_password PASSWORD

and then access the web server at [http://localhost:9344/](http://localhost:9344/)